embassy-nrf

Crates

git

Versions

nrf54l10-app-s

Flavors

Fifothreshold

Struct Fifothreshold 

#[repr(transparent)]
pub struct Fifothreshold(pub u32);
FIFO threshold register.

Tuple Fields

0: u32

Implementations

Source

impl Fifothreshold

pub const fn fifothreshold(&self) -> u8

FIFO level threshold below which the module leaves the idle state to refill the FIFO. Expressed in number of 128bit blocks.

pub const fn set_fifothreshold(&mut self, val: u8)

FIFO level threshold below which the module leaves the idle state to refill the FIFO. Expressed in number of 128bit blocks.